@@ -49,7 +49,7 @@
 #' @author Charlie Gao \email{charlie.gao@@shikokuchuo.net}
 #'     (\href{https://orcid.org/0000-0002-0750-061X}{ORCID})
 #'
-#' @importFrom mirai is_error_value unresolved
+#' @importFrom nanonext is_error_value unresolved
 #' @importFrom later later
 #' @importFrom promises as.promise promise
 #'
@@ -58,7 +58,7 @@
 #'
 NULL
 
-.. <- `[[<-`(new.env(), "freq", 0.1)
+. <- `[[<-`(new.env(hash = FALSE), "freq", 0.1)
 
 #' Make 'Mirai' 'Promise'
 #'
@@ -92,8 +92,8 @@ as.promise.mirai <- function(x)
     function(resolve, reject) {
       query <- function()
         if (unresolved(x))
-          later(query, delay = ..[["freq"]]) else
-            if (is_error_value(value <- .subset2(x, "data")))
+          later(query, delay = .[["freq"]]) else
+            if (is_error_value(value <- .subset2(x, "value")))
               reject(value) else
                 resolve(value)
       query()
@@ -127,7 +127,7 @@ as.promise.recvAio <- as.promise.mirai
 polling <- function(freq = 100L) {
 
   is.numeric(freq) || stop("'freq' must be a numeric value")
-  `[[<-`(.., "freq", freq / 1000L)
+  `[[<-`(., "freq", freq / 1000L)
   invisible()
 
 }
